@@ -253,6 +253,24 @@ void Viewer::next()
     shouldOpenPrevious = false;
 }
 
+void Viewer::left()
+{
+    if (doubleMangaPage) {
+        next();
+    } else {
+        prev();
+    }
+}
+
+void Viewer::right()
+{
+    if (doubleMangaPage) {
+        prev();
+    } else {
+        next();
+    }
+}
+
 void Viewer::prev()
 {
     direction = -1;
@@ -611,7 +629,7 @@ void Viewer::keyPressEvent(QKeyEvent *event)
                  key == ShortcutsManager::getShortcutsManager().getShortcut(MOVE_UP_ACTION_Y) ||
                  key == ShortcutsManager::getShortcutsManager().getShortcut(MOVE_LEFT_ACTION_Y) ||
                  key == ShortcutsManager::getShortcutsManager().getShortcut(MOVE_RIGHT_ACTION_Y)) {
-            QAbstractScrollArea::keyPressEvent(event);
+            moveAction(key);
             emit backgroundChanges();
         }
 
@@ -634,6 +652,26 @@ void Viewer::keyPressEvent(QKeyEvent *event)
         QAbstractScrollArea::keyPressEvent(event);
 }
 
+void Viewer::moveAction(const QKeySequence &key)
+{
+    int _key = 0;
+
+    if (key == ShortcutsManager::getShortcutsManager().getShortcut(MOVE_DOWN_ACTION_Y))
+        _key = Qt::Key_Down;
+
+    else if (key == ShortcutsManager::getShortcutsManager().getShortcut(MOVE_UP_ACTION_Y))
+        _key = Qt::Key_Up;
+
+    else if (key == ShortcutsManager::getShortcutsManager().getShortcut(MOVE_LEFT_ACTION_Y))
+        _key = Qt::Key_Left;
+
+    else if (key == ShortcutsManager::getShortcutsManager().getShortcut(MOVE_RIGHT_ACTION_Y))
+        _key = Qt::Key_Right;
+
+    QKeyEvent _event = QKeyEvent(QEvent::KeyPress, _key, Qt::NoModifier);
+    QAbstractScrollArea::keyPressEvent(&_event);
+}
+
 static void animateScroll(QPropertyAnimation &scroller, const QScrollBar &scrollBar, int delta)
 {
     int deltaNotFinished = 0;
@@ -889,6 +927,13 @@ void Viewer::doublePageSwitch()
     Configuration::getConfiguration().setDoublePage(doublePage);
 }
 
+void Viewer::setMangaWithoutStoringSetting(bool manga)
+{
+    doubleMangaPage = manga;
+    render->setManga(manga);
+    goToFlow->setFlowRightToLeft(doubleMangaPage);
+}
+
 void Viewer::doubleMangaPageSwitch()
 {
     doubleMangaPage = !doubleMangaPage;
@@ -1026,6 +1071,11 @@ void Viewer::updateZoomRatio(int ratio)
     updateContentSize();
 }
 
+bool Viewer::getIsMangaMode()
+{
+    return doubleMangaPage;
+}
+
 void Viewer::updateConfig(QSettings *settings)
 {
     goToFlow->updateConfig(settings);
