@@ -2,8 +2,9 @@
 #define __YACREADER_GLOBAL_H
 
 #include <QStandardPaths>
+#include <QDataStream>
 
-#define VERSION "9.7.1"
+#define VERSION "9.8.1"
 
 #define REMOTE_BROWSE_PERFORMANCE_WORKAROUND "REMOTE_BROWSE_PERFORMANCE_WORKAROUND"
 
@@ -36,8 +37,7 @@ enum YACReaderErrors {
 enum SearchModifiers {
     NoModifiers = 0,
     OnlyRead,
-    OnlyUnread,
-    ByAuthor
+    OnlyUnread
 };
 
 enum LabelColors {
@@ -55,9 +55,26 @@ enum LabelColors {
     YDark
 };
 
+struct OpenComicSource {
+    enum Source {
+        Folder = 0,
+        ReadingList
+    };
+
+    Source source;
+    qulonglong sourceId;
+};
+
+QDataStream &operator<<(QDataStream &stream, const OpenComicSource &source);
+QDataStream &operator>>(QDataStream &stream, OpenComicSource &source);
+
 QString getSettingsPath();
 QString colorToName(LabelColors colors);
 QString labelColorToRGBString(LabelColors color);
 
 }
+
+Q_DECLARE_METATYPE(YACReader::OpenComicSource::Source)
+Q_DECLARE_METATYPE(YACReader::OpenComicSource)
+
 #endif
